<?php
/**
 * simpler functions and definitions
 *
 * @package simpler
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 750; /* pixels */
}

if ( ! function_exists( 'simpler_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function simpler_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on simpler, use a find and replace
	 * to change 'simpler' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'simpler', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
        // Full width pages
        add_image_size('simpler-large-thumb', 1200, 653, true);
        // Posts with sidbar and index
        add_image_size('simpler-medium-thumb', 735, 400, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'simpler' ),
                'social' => __( 'Social Menu', 'simpler'),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

}
endif; // simpler_setup
add_action( 'after_setup_theme', 'simpler_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function simpler_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'simpler' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'simpler_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function simpler_scripts() {
        // Enqueue the Source Sans Pro font 
        wp_enqueue_style( 'simpler-google-fonts', '//fonts.googleapis.com/css?family=Source+Sans+Pro:200,300,400,600,700,900,200italic,300italic,400italic,600italic,700italic,900italic&subset=latin,latin-ext,vietnamese' );

        // Enqueue the Font Awesome font
        wp_enqueue_style( 'simpler-font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
        
        wp_enqueue_style( 'simpler-style', get_stylesheet_uri() );
              
        if (is_page_template('page-templates/page-nosidebar.php')) {
            wp_enqueue_style( 'simpler-page-nosidebar-style' , get_template_directory_uri() . '/layouts/no-sidebar.css');
        } 
        
	wp_enqueue_script( 'simpler-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'simpler-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

        // Enqueue the superfish script
        wp_enqueue_script( 'simpler-superfish', get_template_directory_uri() . '/js/superfish.js', array('jquery'), '20141010', true );
        wp_enqueue_script( 'simpler-superfish-settings', get_template_directory_uri() . '/js/superfish-settings.js', array('simpler-superfish'), '20141010', true );
	
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'simpler_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
